@@ -23,3 +23,11 @@ class RemoteFileRemovedError(GLinkError):
 
 class ConflictError(GLinkError):
     pass
+
+
+class MissingDataError(GLinkError):
+    pass
+
+
+class UnspecifiedUserError(GLinkError):
+    pass
